pbd_durspec_cumdensity: Cumulative density of duration of speciation under protracted birth-death model of diversification
Description
pbd_durspec_cumdensity computes the cumulative density of the duration of speciation under the protracted speciation model for a given set of parameters
Usage
pbd_durspec_cumdensity(
pars,
tau
)
Arguments
pars
Vector of parameters:
pars[1] corresponds to b (= la_3 in Etienne & Rosindell R2012) = speciation initiation rate
pars[2] corresponds to la_1 (= la_2 in Etienne & Rosindell 2012) = speciation completion rate
pars[3]
tau
Value of the duration of speciation at which the cumulative density must be computed
Value
The cumulative density of the duration of speciation